@@ -4,42 +4,41 @@ Client code.
 Main entry point: :func:`open_client`.
 """
 
-import anyio
-import socket
+import logging
 import os
-from typing import Tuple
-from contextlib import asynccontextmanager, AsyncExitStack
+import socket
+from contextlib import AsyncExitStack, asynccontextmanager
 from inspect import iscoroutine
+from typing import Tuple
 
-from asyncscope import scope, Scope, main_scope
+import anyio
+from asyncscope import Scope, main_scope, scope
 
-from .util import (
-    attrdict,
-    gen_ssl,
-    num2byte,
-    byte2num,
-    PathLongener,
-    NotGiven,
-    combine_dict,
-    ValueEvent,
-    Path,
-    create_queue,
-    DelayedRead,
-    DelayedWrite,
-)
+from .codec import packer, stream_unpacker
 from .default import CFG
 from .exceptions import (
+    CancelledError,
     ClientAuthMethodError,
     ClientAuthRequiredError,
     ServerClosedError,
     ServerConnectionError,
     ServerError,
     error_types,
-    CancelledError,
 )
-from .codec import packer, stream_unpacker
-
-import logging
+from .util import (
+    DelayedRead,
+    DelayedWrite,
+    NotGiven,
+    Path,
+    PathLongener,
+    ValueEvent,
+    attrdict,
+    byte2num,
+    combine_dict,
+    create_queue,
+    gen_ssl,
+    num2byte,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -60,19 +59,10 @@ __all__ = ["NoData", "ManyData", "open_client", "client_scope", "StreamedRequest
 
 
 class AsyncValueEvent(ValueEvent):
-    def set(self, value):
-        super().set(value)
-        return anyio.DeprecatedAwaitable(self.set)
-
-    def set_error(self, exc):
-        super().set_error(exc)
-        return anyio.DeprecatedAwaitable(self.set_error)
-
     def cancel(self):
         if self.scope is not None:
             self.scope.cancel()
         super().set_error(CancelledError())
-        return anyio.DeprecatedAwaitable(self.cancel)
 
 
 class NoData(ValueError):
@@ -167,7 +157,9 @@ class StreamedRequest:
         return msg.pop("wseq", 0)
 
     async def _send_ack(self, seq):
-        await self._client._send(seq=self.seq, state="ack", ack=seq)
+        msg = dict(seq=self.seq, state="ack", ack=seq)
+        logger.debug("Send %s", msg)
+        await self._client._send(**msg)
 
     async def set(self, msg):
         """Called by the read loop to process a command's result"""
@@ -183,6 +175,7 @@ class StreamedRequest:
             except anyio.BrokenResourceError:
                 raise cls(msg.error)
             return
+        logger.debug("Reply %s", msg)
         state = msg.get("state", "")
 
         if state == "start":
@@ -249,7 +242,6 @@ class StreamedRequest:
         except CancelledError:
             raise StopAsyncIteration  # just terminate
         self._path_long(res)
-        logger.debug("OneResult: %s", res)
         return res
 
     async def send(self, **params):
@@ -263,10 +255,11 @@ class StreamedRequest:
             params["state"] = "start"
         elif self._stream == 2 and params.get("state", "") == "end":
             self._stream = None
-        logger.debug("Send %s", {"seq": self.seq, **params})
         if self.dw is not None:
             params["wseq"] = await self.dw.next_seq()
-        await self._client._send(seq=self.seq, **params)
+        msg = dict(seq=self.seq, **params)
+        logger.debug("Send %s", msg)
+        await self._client._send(**msg)
 
     async def recv(self):
         return await self.__anext__()
@@ -286,7 +279,9 @@ class StreamedRequest:
         await self.qr.close_sender()
         await self.qr.close_receiver()
         if self._stream == 2:
-            await self._client._send(seq=self.seq, state="end")
+            msg = dict(seq=self.seq, state="end")
+            logger.debug("Send %s", msg)
+            await self._client._send(**msg)
             if timeout is not None:
                 with anyio.move_on_after(timeout):
                     try:
@@ -507,7 +502,7 @@ class Client:
                         try:
                             await self._handle_msg(msg)
                         except ClosedResourceError:
-                            raise RuntimeError(msg)
+                            return
 
                     if self._socket is None:
                         break
@@ -574,7 +569,8 @@ class Client:
             return res
 
         res = await res.get()
-        logger.debug("Result %s", res)
+        if isinstance(res, dict):
+            logger.debug("Result %s", res)
 
         if iter is True and not isinstance(res, StreamedRequest):
 
@@ -958,15 +954,14 @@ class Client:
     def msg_monitor(self, topic: Tuple[str], raw: bool = False):
         """
         Return an async iterator of tunneled messages. This receives
-        all messages sent using :meth:`msg_send` with the same tag.
+        all messages sent using :meth:`msg_send` with the same topic.
 
         Args:
-            tag: the topic / "user:" tag to monitor.
-                 The first character may not be '+'.
-            raw: If ``True``, will not try to msgpack-decode incoming
-                 messages.
+            topic: the topic to monitor.
+            raw: If ``True``, will not try to msgpack-decode incoming messages.
 
-        Returns: a dict.
+        Returns: an iterator yielding a dict.
+            topic: actual topic the message was received at.
             data: decoded data. Not present when ``raw`` is set or the
                   decoder raised an exception.
             raw: un-decoded data. Not present when '`raw`` is not set and
@@ -985,11 +980,10 @@ class Client:
     def msg_send(self, topic: Tuple[str], data=None, raw: bytes = None):
         """
         Tunnel a user-tagged message. This sends the message
-        to all active callers of :meth:`msg_monitor` which use the same tag.
+        to all active callers of :meth:`msg_monitor` which use the same topic.
 
         Args:
-            tag: the "user:" tag to send to.
-                 The first character may not be '+'.
+            topic: the MQTT topic to send to.
             data: to-be-encoded data (anything ``msgpack`` can process).
             raw: raw binary data to send, mutually exclusive with ``data``.
         """
