@@ -1,9 +1,19 @@
 # command line interface
 
-import asyncclick as click
 import sys
 
-from distkv.util import yprint, NotGiven, yload, P, Path, attr_args, process_args, PathLongener
+import asyncclick as click
+
+from distkv.util import (
+    NotGiven,
+    P,
+    Path,
+    PathLongener,
+    attr_args,
+    process_args,
+    yload,
+    yprint,
+)
 
 
 @click.group(invoke_without_command=True)  # pylint: disable=undefined-variable
