@@ -1,65 +1,74 @@
 # Local server
 from __future__ import annotations
 
-import os
 import io
+import os
 import signal
 import time
+
 import anyio
 from anyio.abc import SocketAttribute
 
-from .util import create_queue, DelayedRead, DelayedWrite
+from .util import DelayedRead, DelayedWrite, create_queue
 
 try:
     from contextlib import asynccontextmanager
 except ImportError:
     from async_generator import asynccontextmanager
-from typing import Any, Dict
-from range_set import RangeSet
-from functools import partial
-from asyncactor import Actor, GoodNodeEvent, RecoverEvent, RawMsgEvent
-from asyncactor import TagEvent, UntagEvent, DetagEvent
-from asyncactor.backend import get_transport
-from pprint import pformat
-from collections.abc import Mapping
-
-from .model import NodeEvent, Node, Watcher, UpdateEvent, NodeSet
-from .types import RootEntry, ConvNull, NullACL, ACLFinder, ACLStepper
-from .actor.deletor import DeleteActor
-from .default import CFG
-from .codec import packer, unpacker, stream_unpacker
-from .backend import get_backend
-from .util import (
-    attrdict,
-    PathShortener,
-    PathLongener,
-    MsgWriter,
-    MsgReader,
-    combine_dict,
-    drop_dict,
-    run_tcp_server,
-    gen_ssl,
-    num2byte,
-    byte2num,
-    NotGiven,
-    ValueEvent,
-    Path,
-    P,
-)
-from .exceptions import (
-    ClientError,
-    ClientChainError,
-    NoAuthError,
-    CancelledError,
-    ACLError,
-    ServerError,
-    ServerClosedError,
-    ServerConnectionError,
-)
-from . import client as distkv_client  # needs to be mock-able
-from . import _version_tuple
 
 import logging
+from collections.abc import Mapping
+from functools import partial
+from pprint import pformat
+from typing import Any, Dict
+
+from asyncactor import (
+    Actor,
+    DetagEvent,
+    GoodNodeEvent,
+    RawMsgEvent,
+    RecoverEvent,
+    TagEvent,
+    UntagEvent,
+)
+from asyncactor.backend import get_transport
+from range_set import RangeSet
+
+from . import _version_tuple
+from . import client as distkv_client  # needs to be mock-able
+from .actor.deletor import DeleteActor
+from .backend import get_backend
+from .codec import packer, stream_unpacker, unpacker
+from .default import CFG
+from .exceptions import (
+    ACLError,
+    CancelledError,
+    ClientChainError,
+    ClientError,
+    NoAuthError,
+    ServerClosedError,
+    ServerConnectionError,
+    ServerError,
+)
+from .model import Node, NodeEvent, NodeSet, UpdateEvent, Watcher
+from .types import ACLFinder, ACLStepper, ConvNull, NullACL, RootEntry
+from .util import (
+    MsgReader,
+    MsgWriter,
+    NotGiven,
+    P,
+    Path,
+    PathLongener,
+    PathShortener,
+    ValueEvent,
+    attrdict,
+    byte2num,
+    combine_dict,
+    drop_dict,
+    gen_ssl,
+    num2byte,
+    run_tcp_server,
+)
 
 Stream = anyio.abc.ByteStream
 
@@ -957,9 +966,9 @@ class ServerClient:
         if "chain" in msg:
             if msg.chain is None:
                 if entry.data is not NotGiven:
-                    raise ClientChainError("Entry already exists at {msg.path}")
+                    raise ClientChainError(f"Entry already exists at {msg.path}")
             elif entry.data is NotGiven:
-                raise ClientChainError("Entry is new at {msg.path}")
+                raise ClientChainError(f"Entry is new at {msg.path}")
             elif entry.chain != msg.chain:
                 raise ClientChainError(
                     f"Chain is {entry.chain !r} not {msg.chain !r} for {msg.path}"
@@ -1096,7 +1105,7 @@ class ServerClient:
             t = self.tasks[msg.task]
         except KeyError:
             return False
-        await t.cancel()
+        t.cancel()
         return True
 
     async def cmd_set_auth_typ(self, msg):
@@ -1262,12 +1271,12 @@ class _RecoverControl:
                 lh.append(n)
             self.local_history = lh
             if not lh:
-                await self.cancel()
+                self.cancel()
 
     def __hash__(self):
         return id(self)
 
-    async def cancel(self):
+    def cancel(self):
         self.scope.cancel()
         rt = self.server._recover_tasks
         for node in self.local_history:
@@ -1277,7 +1286,7 @@ class _RecoverControl:
         for evt in list(self._waiters.values()):
             evt.set()
 
-    async def set(self, n):
+    def set(self, n):
         evt = self._waiters.get(n, None)
         if evt is None:
             evt = anyio.Event()
@@ -1694,7 +1703,7 @@ class Server:
             # did this message pre-empt our own transmission?
             rec = self._recover_tasks.get(msg.node, None)
             if rec is not None:
-                await rec.set(1)
+                rec.set(1)
                 self.logger.debug("Step1: %r triggered by %s", rec, msg.node)
 
         # Step 2
@@ -1718,7 +1727,7 @@ class Server:
             # did this message pre-empt our own transmission?
             rec = self._recover_tasks.get(msg.node, None)
             if rec is not None:
-                await rec.set(2)
+                rec.set(2)
                 self.logger.debug("Step2: %r triggered by %s", rec, msg.node)
 
             if nn > 0:
@@ -2227,7 +2236,7 @@ class Server:
                     # been started (because we saw another merge)
                     self.logger.debug("SplitRecover %d: finished @%d", t._id, t.tock)
                     self.seen_missing = {}
-                    await t.cancel()
+                    t.cancel()
 
     async def _send_missing(self, force=False):
         msg = dict()
@@ -2431,7 +2440,9 @@ class Server:
 
                 await mw.flush()
                 if done is not None:
-                    await done.set(done_val)
+                    s = done.set(done_val)
+                    if s is not None:
+                        await s
 
                 cnt = 0
                 while True:
@@ -2483,7 +2494,7 @@ class Server:
                 done.set_error(err)
             finally:
                 with anyio.CancelScope(shield=True):
-                    await sd.set()
+                    sd.set()
 
     async def run_saver(self, path: str = None, stream=None, save_state=False, wait: bool = True):
         """
@@ -2514,14 +2525,14 @@ class Server:
         # At this point the new saver is operational, so we cancel the old one(s).
         while self._savers is not None and self._savers[0][0] is not res:
             s, sd = self._savers.pop(0)
-            await s.cancel()
+            s.cancel()
             await sd.wait()
 
     async def _sigterm(self):
         with anyio.open_signal_receiver(signal.SIGTERM) as r:
             async for s in r:
                 for s, sd in self._savers:
-                    await s.cancel()
+                    s.cancel()
                     await sd.wait()
                 break
         os.kill(os.getpid(), signal.SIGTERM)
